@@ -3,7 +3,7 @@ import pytest
 import httpx
 
 
-@pytest.mark.usefixtures("async_environment")
+@pytest.mark.anyio
 async def test_read_timeout(server):
     timeout = httpx.Timeout(None, read=1e-6)
 
@@ -12,7 +12,7 @@ async def test_read_timeout(server):
             await client.get(server.url.copy_with(path="/slow_response"))
 
 
-@pytest.mark.usefixtures("async_environment")
+@pytest.mark.anyio
 async def test_write_timeout(server):
     timeout = httpx.Timeout(None, write=1e-6)
 
@@ -22,7 +22,7 @@ async def test_write_timeout(server):
             await client.put(server.url.copy_with(path="/slow_response"), content=data)
 
 
-@pytest.mark.usefixtures("async_environment")
+@pytest.mark.anyio
 @pytest.mark.network
 async def test_connect_timeout(server):
     timeout = httpx.Timeout(None, connect=1e-6)
@@ -33,7 +33,7 @@ async def test_connect_timeout(server):
             await client.get("http://10.255.255.1/")
 
 
-@pytest.mark.usefixtures("async_environment")
+@pytest.mark.anyio
 async def test_pool_timeout(server):
     limits = httpx.Limits(max_connections=1)
     timeout = httpx.Timeout(None, pool=1e-4)
@@ -42,3 +42,14 @@ async def test_pool_timeout(server):
         with pytest.raises(httpx.PoolTimeout):
             async with client.stream("GET", server.url):
                 await client.get(server.url)
+
+
+@pytest.mark.anyio
+async def test_async_client_new_request_send_timeout(server):
+    timeout = httpx.Timeout(1e-6)
+
+    async with httpx.AsyncClient(timeout=timeout) as client:
+        with pytest.raises(httpx.TimeoutException):
+            await client.send(
+                httpx.Request("GET", server.url.copy_with(path="/slow_response"))
+            )
